## Script (Python) "getEventDictDay"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=event, type='C', hourID=None
##title=Get dictionary of Event info for day view
##
"""
returns a dictionary of useful objects for Events for the Day view  

modified for CalendarX 0.4.8 for untitled events
Released under the GPL (see LICENSE.txt)
event types: 
   'C' for continuing event (above main calendar view)
   'E' for normal event (in main calendar view)
   'L' for later event (below main calendar view)
"""
request = container.REQUEST

#get from Property Sheets (true or false right now)
ampm = context.getCXAttribute('hoursDisplay') == '12ampm'
dayviewstarthour = int(context.getCXAttribute('dayViewStartHour'))
dayviewendhour = int(context.getCXAttribute('dayViewEndHour'))

#get from request (querystring), or default
try: 
    currentDateTemp = request.currentDate
    currentDate = DateTime(str(currentDateTemp))
except: 
    currentDateTemp = DateTime()
    currentDate = DateTime(str(currentDateTemp))


#calculate these DateTimes and related useful objects
startDate = context.getStartOfDay(currentDate,dayviewstarthour)
endDate = context.getEndOfDay(currentDate,dayviewendhour)
nextDate = (currentDate + 1).Date()
prevDate = (currentDate - 1).Date()
eventstart = DateTime(str(event.start))
eventend = DateTime(str(event.end))
hoursInDay = dayviewendhour - dayviewstarthour
hoursInView = 1*hoursInDay

#display parameters common to ALL event types
eventurl =  str(event.getURL())+'/view'
eventState = event.review_state
eventtitle = str(event.Title)
if not eventtitle:
    eventtitle = 'untitled'
portaltype = str(event.Type)
syear = str(eventstart.year())
smonth = eventstart.aMonth()
sday = str(eventstart.day())
stime = test(ampm, eventstart.AMPMMinutes(), eventstart.TimeMinutes() + ' h')
eyear = str(eventend.year())
emonth = eventend.aMonth()
eday = str(eventend.day())
etime = test(ampm, eventend.AMPMMinutes(), eventend.TimeMinutes() + ' h')


#calculate jsStart and jsEnd: integer range of cells in view for hightlighting
if type == 'C':    #FOR CONTINUING EVENTS
    howManyHours = context.getNumOfHours(startDate, eventend, dayviewstarthour, dayviewendhour)
    jsStart = dayviewstarthour + 1   #ONLY highlights the hours below, not the cEvents cell
    jsEnd = dayviewstarthour + howManyHours
    jsEndIfAllDay = dayviewstarthour + hoursInView
  #the following test() is for events ending ON THE HOUR, so they don't spill over into the next hour upon rollover.
    jsEndIfNotAllDay = test(eventend.minute(),1 + jsEnd,jsEnd)
    jsEnd = test(jsEndIfNotAllDay < jsEndIfAllDay, jsEndIfNotAllDay, jsEndIfAllDay)
  #test() to make sure End is not prior to Start
    jsEnd = test(jsEnd < jsStart, jsStart, jsEnd)
  #generate the eventstring
    eventstring = '<strong>'+eventtitle+'</strong> (start: '+stime+' - '+smonth+' '+sday+', '+syear+' | end: '+etime+' - '+emonth+' '+eday+', '+eyear+')'


#calculate jsStart and jsEnd: integer range of cells in view for hightlighting
if type == 'E':    #FOR EVENTS IN THE REGULAR DAY by hour TABLE
    howManyHours = context.getNumOfHours(eventstart, eventend)
    howManyHours = test(eventstart.minute() > eventend.minute(),howManyHours+1,howManyHours)
    jsStart = hourID
    jsEnd = hourID + howManyHours
    jsEndIfAllDay = dayviewendhour
  #the following test() is for events ending ON THE HOUR, so they don't spill over into the next hour upon rollover.
    jsEndIfNotAllDay = test(eventend.minute(),jsEnd,jsEnd-1)
    jsEnd = test(jsEndIfNotAllDay < jsEndIfAllDay, jsEndIfNotAllDay, jsEndIfAllDay)
  #test() to make sure End is not prior to Start
    jsEnd = test(jsEnd < jsStart, jsStart, jsEnd)
  #generate the eventstring
    eventstring = '<strong>'+eventtitle+'</strong> (start: '+stime+' - '+smonth+' '+sday+', '+syear+' | end: '+etime+' - '+emonth+' '+eday+', '+eyear+')'



#calculate jsStart and jsEnd: integer range of cells in view for hightlighting
if type == 'L':    #FOR LATER EVENTS 
    jsStart = dayviewendhour + 1
    jsEnd = jsStart
  #generate the eventstring
    eventstring = '<strong>'+eventtitle+'</strong> (start: '+stime+' - '+smonth+' '+sday+', '+syear+' | end: '+etime+' - '+emonth+' '+eday+', '+eyear+')'




#marshall all these into a dictionary
eddict = {
         'eventurl':eventurl, 
         'eventstart':eventstart, 
         'eventend':eventend, 
         'jsStart':jsStart, 
         'jsEnd':jsEnd, 
         'eventurl':eventurl,
         'eventState':eventState,
         'eventtitle':eventtitle,
         'portaltype':portaltype,
         'syear':syear,
         'smonth':smonth,
         'sday':sday,
         'stime':stime,
         'eyear':eyear,
         'emonth':emonth,
         'eday':eday,
         'etime':etime,
         'eventstring':eventstring, 
        }

return eddict

