## Script (Python) "getEventDictWeekbyhour"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=event, type='C', hourID=None
##title=Get dictionary of Event info for weekbyhour view
##
"""
returns a dictionary of useful objects for Events for the Weekbyhour view  

modified for CalendarX 0.4.13 fixed <br> to <br/> for W3C valid HTML
Released under the GPL (see LICENSE.txt)
event types: 
   'C' for continuing event (above main calendar view)
   'E' for normal event (in main calendar view)
   'L' for later event (below main calendar view)
hourID only submitted with 'E' events
"""
request = container.REQUEST

#get from Property Sheets (true or false right now)
ampm = context.getCXAttribute('hoursDisplay') == '12ampm'
weekviewstarthour = int(context.getCXAttribute('dayViewStartHour'))
weekviewendhour = int(context.getCXAttribute('dayViewEndHour'))

#get from request (querystring), or default
try: 
    currentDateTemp = request.currentDate
    currentDate = DateTime(str(currentDateTemp))
except: 
    currentDateTemp = DateTime()
    currentDate = DateTime(str(currentDateTemp))


#calculate these DateTimes and related useful objects
startDate = context.getStartOfWeek(currentDate,weekviewstarthour)
endDate = context.getEndOfWeek(currentDate,weekviewendhour)
nextDate = (currentDate + 7).Date()
prevDate = (currentDate - 7).Date()
eventstart = DateTime(str(event.start))
eventend = DateTime(str(event.end))
hoursInDay = weekviewendhour - weekviewstarthour
hoursInView = 7*hoursInDay

#display parameters common to ALL event types
eventurl =  str(event.getURL())+'/view'
eventState = event.review_state
eventtitle = str(event.Title)
if not eventtitle:
    eventtitle = 'untitled'
portaltype = str(event.Type)
syear = str(eventstart.year())
smonth = eventstart.aMonth()
sday = str(eventstart.day())
stime = test(ampm, eventstart.AMPMMinutes(), eventstart.TimeMinutes() + ' h')
eyear = str(eventend.year())
emonth = eventend.aMonth()
eday = str(eventend.day())
etime = test(ampm, eventend.AMPMMinutes(), eventend.TimeMinutes() + ' h')



#calculate jsStart and jsEnd: integer range of cells in view for hightlighting
if type == 'C':    #FOR CONTINUING EVENTS
    daysTilWeekEnd = context.getNumOfDays(eventstart, startDate+6, daysordates='days')
    daysTilWeekEnd = test(daysTilWeekEnd > 6, 6, daysTilWeekEnd)
    jsStart  = weekviewstarthour + 1 + (6-daysTilWeekEnd)*hoursInDay
    jsEndIfAllWeek = weekviewstarthour + hoursInView
  #datetime at start of viewday that event shows up on (at jsStart)
    dtDayStart = startDate + 6 - daysTilWeekEnd       
    hoursToShow = context.getNumOfHours(dtDayStart, eventend, weekviewstarthour, weekviewendhour)
    jsEnd = jsStart + hoursToShow
  #then test() for ending ON THE HOUR, so events don't spill over into the next hour upon rollover.
  #  and test() for ending OFF THE VIEW, so events don't spill over into the next hour upon rollover.
    eventEndIsInView = weekviewstarthour <= eventend.hour() < weekviewendhour
    jsEndIfNotAllWeek = test(eventend.minute() == 0 or not eventEndIsInView, jsEnd - 1, jsEnd)
    jsEnd = test(jsEndIfNotAllWeek < jsEndIfAllWeek, jsEndIfNotAllWeek, jsEndIfAllWeek)
  #test() to make sure End is not prior to Start
    jsEnd = test(jsEnd < jsStart, jsStart, jsEnd)
  #generate the eventstring
    eventstring = '<strong>'+eventtitle+'</strong> (start: '+stime+' - '+smonth+' '+sday+', '+syear+' | end: '+etime+' - '+emonth+' '+eday+', '+eyear+')'



#calculate jsStart and jsEnd: integer range of cells in view for hightlighting
if type == 'E':    #FOR EVENTS IN THE REGULAR WEEKBYHOUR TABLE
    jsStart = hourID
    howManyHours = context.getNumOfHours(eventstart, eventend, weekviewstarthour, weekviewendhour)
    jsEnd = jsStart + howManyHours
    jsEndIfAllWeek = weekviewstarthour + hoursInView
  #the following test() is for events ending ON THE HOUR, so they don't spill over into the next hour upon rollover.
    jsEndIfNotAllWeek = test(eventend.minute() == 0, jsEnd-1, jsEnd)
    jsEnd = test(jsEnd < jsEndIfAllWeek, jsEndIfNotAllWeek, jsEndIfAllWeek)
  #test() to make sure End is not prior to Start
    jsEnd = test(jsEnd < jsStart, jsStart, jsEnd)
  #generate the eventstring
    sameday = (eday == sday) and (emonth == smonth) and (eyear == syear)
    datestring = (sameday and '%s - %s'%(stime, etime)) or '%s %s - %s %s'%(smonth, sday, emonth, eday)
    eventstring = '<strong>'+eventtitle+'</strong><br/> '+datestring



#calculate jsStart and jsEnd: integer range of cells in view for hightlighting
#only highlight ONE Day, the day where the event starts (albeit late)
if type == 'L':    #FOR LATER EVENTS 
    firstEveOfWeek = endDate - 6
    evesTilEventStart = context.getNumOfDays(firstEveOfWeek, eventstart)
    jsStart = weekviewstarthour + hoursInView + 1 + evesTilEventStart
  #test for wee hours events, bring them back to the previous day for highlighting
    jsStart = test(eventstart.hour() < weekviewstarthour and eventstart < endDate, jsStart-1, jsStart)
    jsEnd = jsStart
  #generate the eventstring
    eventstring = '<strong>'+eventtitle+'</strong> (start: '+stime+' - '+smonth+' '+sday+', '+syear+' | end: '+etime+' - '+emonth+' '+eday+', '+eyear+')'




#marshall all these into a dictionary
ewbhdict = {
         'eventurl':eventurl, 
         'eventstart':eventstart, 
         'eventend':eventend, 
         'jsStart':jsStart, 
         'jsEnd':jsEnd, 
         'eventurl':eventurl,
         'eventState':eventState,
         'eventtitle':eventtitle,
         'portaltype':portaltype,
         'syear':syear,
         'smonth':smonth,
         'sday':sday,
         'stime':stime,
         'eyear':eyear,
         'emonth':emonth,
         'eday':eday,
         'etime':etime,
         'eventstring':eventstring, 
        }

return ewbhdict

